Documentation
¶
Index ¶
Constants ¶
const UserCtxKey = "UserID"
Variables ¶
var ( ErrValidateRemoteStatusFailed = irr.Error("validate remote status failed") ErrValidateRemoteDegraded = irr.Error("validate remote degraded") )
Functions ¶
Types ¶
type Cli ¶
type Cli struct {
AuthNSvrURL string
// contains filtered or unexported fields
}
Cli represents the client used to interact with the IAM server and perform local JWT verification
func (*Cli) RefreshToken ¶
RefreshToken sends a refresh token request to IAM and returns a new token
func (*Cli) ValidateRemote ¶
ValidateRemote tries to validate the token with the IAM server first. If the IAM server is unavailable or gives a degraded response, it performs local JWT validation (long term ticket). Otherwise, it opts for the short ticket.
Click to show internal directories.
Click to hide internal directories.